- Adds ``xoutil.datetime.daterange``.

- Adds ``xoutil.objects.traverse``.

- Adds ``xoutil.fs.makedirs`` and ``xoutil.fs.ensure_filename``.

- The `fill` argument in function ``xoutil.iterators.slides`` now defaults to
  None. This is consistent with the intended usage of ``Unset`` and with the
  semantics of both ``xoutil.iterators.continuously_slides`` and
  ``xoutil.iterators.first_n``.

  Unset, as a default value for parameters, is meant to signify the absence of
  an argument and thus only would be valid if an absent argument had some kind
  of effect *different* from passing the argument.

- Changes ``xoutil.modules.customize`` API to separate options from
  custom attributes.

- Includes a `random` parameter to ``xoutil.uuid.uuid``.
